export interface OAuthConfig {
    clientId: string;
    clientSecret: string;
    redirectUri: string;
    scope: string;
    authorizationUrl: string;
    width?: number;
    height?: number;
}
export interface OAuthData {
    code: string;
    [key: string]: string;
}
export interface OAuthResponse {
    oauthData: OAuthData;
    config: OAuthConfig;
    window: Window;
    interval: number;
}
/**
 * Initiates the OAuth2 flow by constructing the authorization URL
 */
export declare function oauth2(config: OAuthConfig): Promise<{
    url: string;
    config: OAuthConfig;
}>;
/**
 * Opens a popup window for OAuth authentication
 */
export declare function openPopup({ url, config }: {
    url: string;
    config: OAuthConfig;
}): Promise<{
    window: Window;
    config: OAuthConfig;
}>;
/**
 * Polls the popup window for OAuth completion
 */
export declare function pollPopup({ window: popupWindow, config, requestToken }: {
    window: Window;
    config: OAuthConfig;
    requestToken?: Record<string, string>;
}): Promise<OAuthResponse>;
